==> nzbget-0.1.1.tar.gz: nzbget-0.1.1/DownloadJob.h <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2004  Sven Henkel <sidddy@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.5 $
 * $Date: 2004/03/30 12:21:03 $
 *
 */


#ifndef DOWNLOADJOB_H
#define DOWNLOADJOB_H

#include <vector>
#include <string>

#include "Job.h"

class DownloadJob : public Job
{
 public:

    DownloadJob();

    std::vector<char*>* getMessageIDs() { return &this->messageIDs; }

    char* getSubject() { return this->subject; }

    void setSubject(char* sub) { this->subject = sub; }

    void setSize(long long s) { this->size = s; }

    long long getSize() { return this->size; }

    std::vector<char*>* getGroups() { return &this->groups; }

 protected:
    
    std::vector<char*> messageIDs;

    std::vector<char*> groups;

    char* subject;

    long long size;

};

#endif

==> nzbget-0.2.0.tar.gz: nzbget-0.2.0/DownloadJob.h <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2004  Sven Henkel <sidddy@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.5 $
 * $Date: 2004/03/30 12:21:03 $
 *
 */


#ifndef DOWNLOADJOB_H
#define DOWNLOADJOB_H

#include <vector>
#include <string>

#include "Job.h"

class DownloadJob : public Job
{
 public:

    DownloadJob();
	~DownloadJob();

    std::vector<char*>* getMessageIDs() { return &m_MessageIDs; }
    char* getSubject() { return m_szSubject; }
    void SetSubject(const char* szSubject);
    void setSize(long long s) { m_lSize = s; }
    long long getSize() { return m_lSize; }
    std::vector<char*>* getGroups() { return &m_Groups; }

 protected:
    
    std::vector<char*>	m_MessageIDs;
    std::vector<char*>	m_Groups;
	char* 				m_szSubject;
    long long 			m_lSize;

};

#endif
